@@ -167,13 +167,23 @@ class Api(snappi.Api):
                     if len(match) == 0:
                         if error.ErrorLevel == "kWarning":
                             warnings.append(
-                                "IxNet - {0}".format(error.Description)
+                                "IxNet - {0}".format(
+                                    error.Name if error.Description == "" else error.Description
+                                )
                             )
                         if error.ErrorLevel == "kError":
                             errors.append(
-                                "IxNet - {0}".format(error.Description)
+                                "IxNet - {0}".format(
+                                    error.Name if error.Description == "" else error.Description
+                                )
                             )
         # request_detail.errors = errors
+
+        # Need to add this hack as dumping json config throws this exception
+        # Traffic regeneration will be part of set_transmit_state
+        errors = [error for error in errors
+                  if "before trying to generate BGP EVPN traffic" not in error]
+
         if len(errors) > 0:
             self._errors = []
             raise SnappiIxnException(500, errors)
@@ -222,8 +232,8 @@ class Api(snappi.Api):
     def config_ixnetwork(self, config):
         self._config_objects = {}
         self._device_encap = {}
-        self.ixn_objects = IxNetObjects()
-        self.ixn_routes = IxNetObjects()
+        self.ixn_objects = IxNetObjects(self)
+        self.ixn_routes = IxNetObjects(self)
         self._dev_compacted = {}
         self._connect()
         self.capture.reset_capture_request()
